
/* Chrysalide - Outil d'analyse de fichiers binaires
 * global.c - conservation et accès aux variables globales
 *
 * Copyright (C) 2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "global.h"


#include <assert.h>



/* Gestionnaire de tâches parallèles */
static GWorkQueue *_queue = NULL;

/* Projet global actif */
static GStudyProject *_project = NULL;

/* Avertisseur de changement de projet principal */
static current_project_change_cb _project_notify = NULL;



/******************************************************************************
*                                                                             *
*  Paramètres  : queue = nouveau gestionnaire à mémoriser ou NULL.            *
*                                                                             *
*  Description : Définit le gestionnaire de traitements parallèles courant.   *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void set_work_queue(GWorkQueue *queue)
{
    assert(_queue == NULL);

    _queue = queue;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit le gestionnaire de traitements parallèles courant.   *
*                                                                             *
*  Retour      : Gestionnaire de traitements parallèles courant.              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GWorkQueue *get_work_queue(void)
{
    return _queue;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : project = éventuelle adresse du nouveau projet principal.    *
*                                                                             *
*  Description : Définit l'adresse du projet courant.                         *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void set_current_project(GStudyProject *project)
{
    if (_project != NULL)
    {
        _project_notify(_project, false);
        g_object_unref(G_OBJECT(_project));
    }

    _project = project;

    if (_project != NULL)
        _project_notify(_project, true);

}


/******************************************************************************
*                                                                             *
*  Paramètres  : project = éventuel adresse à renvoyer désormais.             *
*                                                                             *
*  Description : Fournit l'adresse du projet courant.                         *
*                                                                             *
*  Retour      : Adresse du projet ouvert ou NULL si aucun (!).               *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GStudyProject *get_current_project(void)
{
    assert(_project != NULL);

    g_object_ref(G_OBJECT(_project));

    return _project;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : notify = procédure à appeler à chaque changement de project. *
*                                                                             *
*  Description : Enregistre une partie de code à avertir en cas de changement.*
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void register_project_change_notification(current_project_change_cb notify)
{
    assert(_project_notify == NULL);

    _project_notify = notify;

}
