
/* Chrysalide - Outil d'analyse de fichiers binaires
 * processors.h - prototypes pour l'enregistrement et la fourniture des architectures supportées
 *
 * Copyright (C) 2015-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _CORE_PROCESSORS_H
#define _CORE_PROCESSORS_H


#include <glib-object.h>
#include <stdbool.h>


#include "../arch/processor.h"



/* Mise en place de mécanismes internes */
typedef bool (* init_arch_fc) (void);

/* Suppression de mécanismes internes */
typedef void (* exit_arch_fc) (void);


/* Enregistre un processeur pour une architecture donnée. */
bool register_processor_type(const char *, const char *, GType, init_arch_fc, exit_arch_fc);

/* Charge les définitions de processeurs "natifs". */
bool load_hard_coded_processors_definitions(void);

/* Décharge toutes les définitions de processeurs. */
void unload_processors_definitions(void);

/* Fournit le nom humain de l'architecture visée. */
const char *get_arch_processor_name(const char *);

/* Fournit le processeur d'architecture correspondant à un type. */
GArchProcessor *get_arch_processor_for_type(const char *);



#endif  /* _CORE_PROCESSORS_H */
